summaryrefslogtreecommitdiffstats
path: root/ppapi/proxy/ppb_file_ref_proxy.cc
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-06 23:42:21 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-06 23:42:21 +0000
commit65165551604da0f53f5f17fbe8e97363b9436cf5 (patch)
tree897e2b8202f24f08b939e30e60a094649fd6d0d3 /ppapi/proxy/ppb_file_ref_proxy.cc
parent5d80114534c28f69de8abf0d45507f0ec8fda217 (diff)
downloadchromium_src-65165551604da0f53f5f17fbe8e97363b9436cf5.zip
chromium_src-65165551604da0f53f5f17fbe8e97363b9436cf5.tar.gz
chromium_src-65165551604da0f53f5f17fbe8e97363b9436cf5.tar.bz2
Rename the shared_impl resource files to give them more regular names.
I keep getting confused between things like AudioImpl and PPB_Audio_Impl. This uses _shared for the names, so now we have _impl, _proxy, and _shared which makes more sense. I also removed the ppb_opengles2_impl file since it was just a forward to the shared version. BUG= TEST= Review URL: http://codereview.chromium.org/8790004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@113290 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi/proxy/ppb_file_ref_proxy.cc')
-rw-r--r--ppapi/proxy/ppb_file_ref_proxy.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/ppapi/proxy/ppb_file_ref_proxy.cc b/ppapi/proxy/ppb_file_ref_proxy.cc
index 5f1a05f..20b522c 100644
--- a/ppapi/proxy/ppb_file_ref_proxy.cc
+++ b/ppapi/proxy/ppb_file_ref_proxy.cc
@@ -16,7 +16,7 @@
#include "ppapi/proxy/plugin_dispatcher.h"
#include "ppapi/proxy/ppapi_messages.h"
#include "ppapi/proxy/serialized_var.h"
-#include "ppapi/shared_impl/file_ref_impl.h"
+#include "ppapi/shared_impl/ppb_file_ref_shared.h"
#include "ppapi/thunk/resource_creation_api.h"
#include "ppapi/thunk/thunk.h"
@@ -28,12 +28,12 @@ using ppapi::thunk::ResourceCreationAPI;
namespace ppapi {
namespace proxy {
-class FileRef : public FileRefImpl {
+class FileRef : public PPB_FileRef_Shared {
public:
explicit FileRef(const PPB_FileRef_CreateInfo& info);
virtual ~FileRef();
// PPB_FileRef_API implementation (not provided by FileRefImpl).
virtual PP_Resource GetParent() OVERRIDE;
virtual int32_t MakeDirectory(PP_Bool make_ancestors,
PP_CompletionCallback callback) OVERRIDE;
@@ -72,7 +72,7 @@ class FileRef : public FileRefImpl {
};
FileRef::FileRef(const PPB_FileRef_CreateInfo& info)
- : FileRefImpl(FileRefImpl::InitAsProxy(), info),
+ : PPB_FileRef_Shared(PPB_FileRef_Shared::InitAsProxy(), info),
next_callback_id_(1) {
}
@@ -28,12 +28,12 @@ using ppapi::thunk::ResourceCreationAPI;
explicit FileRef(const PPB_FileRef_CreateInfo& info);
virtual ~FileRef();
- // PPB_FileRef_API implementation (not provided by FileRefImpl).
+ // PPB_FileRef_API implementation (not provided by PPB_FileRef_Shared).
virtual PP_Resource GetParent() OVERRIDE;
virtual int32_t MakeDirectory(PP_Bool make_ancestors,